@@ -3,7 +3,7 @@ from geo_lookup import get_places_by_type
 from address import AddressParser
 
 def is_a_bool(value, key=None):
-    bool_words = ['y,yes,n,no,true,false,t,f,on,off']
+    bool_words = ['y','yes','n','no','true','false','t','f','on','off']
     return value.lower().strip() in bool_words
 
 
@@ -88,6 +88,13 @@ def is_a_str(value, key=None):
     return True
 
 
+def is_a_text(value, key=None):
+    if not is_a_str(value, key=key):
+        return False
+
+    return len(str(value).strip()) > 90
+
+
 """Geospatial checks. Looks for coordinates, coordinate pairs, address strings, 
 geo text (like country, state, city), zip codes, etc etc. Basically anything 
 you might want to geocode or treat as a point. """
@@ -114,17 +121,23 @@ def is_a_coord(value, key=None, pos=None):
 
 
 def is_a_coord_pair(value, key=None, pos=None):
-    delimeters = [',','|','/',' ']
-    possible_matches = [d for d in delimeters if d in str(value).strip()]
+    delimeters = [',','|','/']
+    disallowed = "(){}[]"
+
+    value = str(value).strip()
+    possible_matches = [d for d in delimeters if d in value]
     
     # if more than one of these is present or none of them, than this isn't 
     # a pair
     if len(possible_matches) != 1:
         return False
 
+    # Get rid of weird shit people put in coord pair columns
+    value = value.translate(None, disallowed)
+
     delimiter = possible_matches[0]
-    
     possible_cords = value.split(delimiter)
+    
     if len(possible_cords) != 2:
         return False
 
@@ -152,6 +165,10 @@ def is_a_place(value, place_type, key=None):
 
     value = str(value).strip()
 
+    non_addrs = ['|','/','?','!','@','$','%']
+    if len([na for na in non_addrs if na in value]) > 0:
+        return False
+
     # If your country's name is longer than 40 characters, you're doing 
     # something wrong.
     if len(value) > 40:
@@ -208,7 +225,7 @@ def is_a_zip(value, key=None, pos=None):
 
     return False
 
-
+ap = AddressParser()
 def is_a_address(value, key=None, pos=None):
     if not is_a_str(value):
         return False
@@ -218,7 +235,6 @@ def is_a_address(value, key=None, pos=None):
     if len(value) > 80:
         return False
 
-    ap = AddressParser()
     address = ap.parse_address(value)
 
     keys = [
